<?php

// Ceci devrait être dans un fichier de config (ou dans une base SQL)
define('DEBUG', TRUE);

function initialize() {
	// Régule la gestion des erreurs
	if (defined('DEBUG') && DEBUG) {
		error_reporting(E_ALL);
		ini_set('display_errors', 'On');
	} else {
		error_reporting(E_ALL);
		ini_set('display_errors', 'Off');
		ini_set('log_errors', 'On');
		ini_set('error_log', sys_get_temp_dir() . '/appli-securite/error.log');
	}

	// Vérifie que les magic quotes sont à off.
	// Il faudrait mettre une alerte dans les logs sinon.
	noMagicQuotes();

	initSession();

	// Dans quels répertoires include/require cherchent-ils les fichiers ?
	// Nécessaire si HTML_QuickForm n'est pas installé par pear.
	set_include_path(
		dirname(__FILE__)
		. PATH_SEPARATOR . get_include_path()
	);

	// Par défaut, toutes les pages sont en UTF-8
	ini_set('default_charset', 'utf-8');
}

/**
 * Initialise la session
 */
function initSession() {
	$sessionsDir = sys_get_temp_dir() . '/appli-securite/sessions';
	if (!is_dir($sessionsDir)) {
		mkdir($sessionsDir, 0700, TRUE);
	}
	ini_set('session.save_path', $sessionsDir);

	ini_set('session.gc_maxlifetime', 60*15); // 15 minutes

	ini_set('session.use_only_cookies', 1) ;
	ini_set('session.use_trans_sid', 0) ;
	session_name('MYSESSID');

	ini_set('session.cookie_httponly', true); // au cas où le navigateur le comprend...

	session_start();
	// Pour vérifier qu'on a affaire au même navigateur sans contraindre l'IP
	// (fiabilité limitée, mais pas d'effet secondaire)
	$signature = md5($_SERVER['HTTP_USER_AGENT']
		.' (ceci est mon sel) ' . $_SERVER['HTTP_ACCEPT_CHARSET']);
	// Création de la session ?
	if (! isset($_SESSION['signature'])) {
		session_regenerate_id(true); // true : option PHP 5.1 pour eﬀacer l’ancienne session
		$_SESSION['signature'] = $signature;
	} elseif ($_SESSION['signature'] !== $signature) {
		die(' Erreur de session ');
	}
}

function initDatabase() {
	$dir = dirname(__FILE__);
	try {
		$db = new PDO('sqlite:' . $dir .'/database.sq3');
		// $db = new PDO('mysql:host=localhost;dbname=Base', 'login', 'mdp');
	} catch (PDOException $e) {
		die('DB error: ' . $e->getMessage());
	}
	return $db;
}

/* Emule le fonctionnement de "magic_quotes_gpc = Off" dans "php.ini".
 *
 * Cf http://fr.php.net/manual/fr/security.magicquotes.disabling.php
 */
function noMagicQuotes()
{
	if (get_magic_quotes_gpc()) {
		$_POST = array_map('stripslashes_deep', $_POST);
		$_GET = array_map('stripslashes_deep', $_GET);
		$_COOKIE = array_map('stripslashes_deep', $_COOKIE);
		$_REQUEST = array_map('stripslashes_deep', $_REQUEST);
	}
}
function stripslashes_deep($value)
{
	$value = is_array($value) ?
		array_map('stripslashes_deep', $value) :
		stripslashes($value);
	return $value;
}

/**
 * Safely encodes an HTTP URL so that it can be printed in HTML.
 *
 * Pas besoin de urlencode() ni rawurlencode() qui servent à encoder
 * un paramètre dans une URL !
 */
function encodeHttpUrl( $url )
{
	if (strncmp($url, 'http://', 7) !== 0) {
		return "";
	}
	return htmlspecialchars($url);
}